@@ -17,7 +17,14 @@ def test():
     """Run unittests for nomnomdata engine tools"""
     import pytest
 
-    pytest.main(["--pyargs", "nomnomdata.tools.engine"])
+    pytest.main(
+        [
+            "--ignore",
+            "nomnomdata/tools/engine/template",
+            "--pyargs",
+            "nomnomdata.tools.engine",
+        ]
+    )
 
 
 cli.add_command(create_new)
